{ pkgs ? import ./nixpkgs-2105.nix {}
, configuration ? ./morph/grid/local/configuration.nix
, includeStorePaths ? false
}:
let
  nixpkgs = import <nixpkgs> {};
  local-grid = "${./.}/morph/grid/local";
  arion-src = nixpkgs.fetchFromGitHub {
    owner = "tp-la";
    repo = "arion";
    rev = "hack";
    sha256 = "0wv4wbzzd926qm81h78v10wyhiaayx2jggpb1ijzk118a543sz84";
  };
  arion-eval = args@{...}: import "${arion-src}/src/nix/eval-composition.nix" ({ inherit pkgs; } // args);
  arion = arion-eval {
    modules = [ "${local-grid}/arion-compose.nix" ];
  };
  bundle = pkgs.dockerTools.mergeImages (
    map (
      { imageName, imageTag, imageExe }:
      pkgs.runCommand "${baseNameOf imageName}.tar.gz"
        {
          inherit imageName;
          passthru = { inherit imageTag; };
          nativeBuildInputs = [ pkgs.pigz ];
        } "${imageExe} | pigz -nT > $out"
      ) arion.config.build.imagesToLoad
  );
  docker-yaml = pkgs.runCommand "docker-compose.yaml"
    { nativeBuildInputs = [ pkgs.gojsontoyaml ]; }
    "${pkgs.gojsontoyaml}/bin/gojsontoyaml <${arion.config.out.dockerComposeYaml} > $out"; 
  package = pkgs.runCommand "privatestorage"
     { preferLocalBuild = true; allowSubstitutes = false; }
     ''
     mkdir -p $out
     ln -sr ${bundle} $out/docker-bundle.tar.gz
     ln -sr ${docker-yaml} $out/docker-compose.yaml
     '';
   pause = pkgs.callPackage ./pause.nix {};
in
  {inherit pkgs arion local-grid bundle arion-eval arion-src docker-yaml package pause;}
